pub enum InteractiveGuestRequest {
PutFile {
local_file: ClientEnd<FileMarker>,
remote_path: String,
responder: InteractiveGuestPutFileResponder,
},
GetFile {
remote_path: String,
local_file: ClientEnd<FileMarker>,
responder: InteractiveGuestGetFileResponder,
},
ExecuteCommand {
command: String,
env: Vec<EnvironmentVariable>,
stdin: Option<Socket>,
stdout: Option<Socket>,
stderr: Option<Socket>,
command_listener: ServerEnd<CommandListenerMarker>,
control_handle: InteractiveGuestControlHandle,
},
Start {
guest_type: GuestType,
name: String,
guest_config: GuestConfig,
responder: InteractiveGuestStartResponder,
},
Shutdown {
responder: InteractiveGuestShutdownResponder,
},
}Expand description
Encapsulates the starting and interaction of a guest. This is primarily a convenience, but also provides an abstraction layer over the interaction client_impl.h and client_operation_state.h files. This abstraction allows reuse of the interaction implementations across Fuchsia processes via FIDL, regardless of the caller language (e.g. Rust).
Variants
PutFile
Take a local file from the Fuchsia host and transfer it to a destination location on the guest under test.
GetFile
Pull a file from the guest under test and copy it to the specified location on the Fuchsia host.
ExecuteCommand
Execute command on the guest under test and return the resulting output, error, and return code.
Fields

env: Vec<EnvironmentVariable>
command_listener: ServerEnd<CommandListenerMarker>
control_handle: InteractiveGuestControlHandleStart
Shutdown
Fields

responder: InteractiveGuestShutdownResponderImplementations
Sourceimpl InteractiveGuestRequest
impl InteractiveGuestRequest
pub fn into_put_file( self, ) -> Option<(ClientEnd<FileMarker>, String, InteractiveGuestPutFileResponder)>
pub fn into_get_file( self, ) -> Option<(String, ClientEnd<FileMarker>, InteractiveGuestGetFileResponder)>
pub fn into_execute_command( self, ) -> Option<(String, Vec<EnvironmentVariable>, Option<Socket>, Option<Socket>, Option<Socket>, ServerEnd<CommandListenerMarker>, InteractiveGuestControlHandle)>
pub fn into_start( self, ) -> Option<(GuestType, String, GuestConfig, InteractiveGuestStartResponder)>
pub fn into_shutdown(self) -> Option<InteractiveGuestShutdownResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL