pub struct InteractiveGuestMarker;Trait Implementations
Sourceimpl Clone for InteractiveGuestMarker
impl Clone for InteractiveGuestMarker
Sourcefn clone(&self) -> InteractiveGuestMarker
fn clone(&self) -> InteractiveGuestMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InteractiveGuestMarker
impl Debug for InteractiveGuestMarker
Sourceimpl DiscoverableProtocolMarker for InteractiveGuestMarker
impl DiscoverableProtocolMarker for InteractiveGuestMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for InteractiveGuestMarker
impl Hash for InteractiveGuestMarker
Sourceimpl Ord for InteractiveGuestMarker
impl Ord for InteractiveGuestMarker
Sourcefn cmp(&self, other: &InteractiveGuestMarker) -> Ordering
fn cmp(&self, other: &InteractiveGuestMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InteractiveGuestMarker
impl PartialEq for InteractiveGuestMarker
Sourceimpl PartialOrd for InteractiveGuestMarker
impl PartialOrd for InteractiveGuestMarker
Sourceimpl ProtocolMarker for InteractiveGuestMarker
impl ProtocolMarker for InteractiveGuestMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.virtualization.guest.interaction.InteractiveGuest"
const DEBUG_NAME: &'static str = "fuchsia.virtualization.guest.interaction.InteractiveGuest"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = InteractiveGuestProxy
type Proxy = InteractiveGuestProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = InteractiveGuestRequestStream
type RequestStream = InteractiveGuestRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = InteractiveGuestSynchronousProxy
type SynchronousProxy = InteractiveGuestSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for InteractiveGuestMarker
impl Eq for InteractiveGuestMarker
impl StructuralPartialEq for InteractiveGuestMarker