pub struct InteractiveGuestProxy { /* private fields */ }Implementations
Sourceimpl InteractiveGuestProxy
impl InteractiveGuestProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.virtualization.guest.interaction/InteractiveGuest.
Sourcepub fn take_event_stream(&self) -> InteractiveGuestEventStream
pub fn take_event_stream(&self) -> InteractiveGuestEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn put_file(
&self,
local_file: ClientEnd<FileMarker>,
remote_path: &str,
) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
pub fn put_file( &self, local_file: ClientEnd<FileMarker>, remote_path: &str, ) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
Take a local file from the Fuchsia host and transfer it to a destination location on the guest under test.
Sourcepub fn get_file(
&self,
remote_path: &str,
local_file: ClientEnd<FileMarker>,
) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
pub fn get_file( &self, remote_path: &str, local_file: ClientEnd<FileMarker>, ) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
Pull a file from the guest under test and copy it to the specified location on the Fuchsia host.
Sourcepub fn execute_command(
&self,
command: &str,
env: &[EnvironmentVariable],
stdin: Option<Socket>,
stdout: Option<Socket>,
stderr: Option<Socket>,
command_listener: ServerEnd<CommandListenerMarker>,
) -> Result<(), Error>
pub fn execute_command( &self, command: &str, env: &[EnvironmentVariable], stdin: Option<Socket>, stdout: Option<Socket>, stderr: Option<Socket>, command_listener: ServerEnd<CommandListenerMarker>, ) -> Result<(), Error>
Execute command on the guest under test and return the resulting output, error, and return code.
pub fn start( &self, guest_type: GuestType, name: &str, guest_config: GuestConfig, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn shutdown(&self) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>