pub struct InteractiveGuestStartRequest {
pub guest_type: GuestType,
pub name: String,
pub guest_config: GuestConfig,
}Fields
guest_type: GuestTypename: Stringguest_config: GuestConfigTrait Implementations
Sourceimpl Debug for InteractiveGuestStartRequest
impl Debug for InteractiveGuestStartRequest
Sourceimpl Decode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for InteractiveGuestStartRequest
impl Decode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for InteractiveGuestStartRequest
Sourceimpl Encode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for &mut InteractiveGuestStartRequest
impl Encode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for &mut InteractiveGuestStartRequest
Sourceimpl<T0: Encode<GuestType, DefaultFuchsiaResourceDialect>, T1: Encode<BoundedString<1024>, DefaultFuchsiaResourceDialect>, T2: Encode<GuestConfig, DefaultFuchsiaResourceDialect>> Encode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
impl<T0: Encode<GuestType, DefaultFuchsiaResourceDialect>, T1: Encode<BoundedString<1024>, DefaultFuchsiaResourceDialect>, T2: Encode<GuestConfig, DefaultFuchsiaResourceDialect>> Encode<InteractiveGuestStartRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
Sourceimpl PartialEq for InteractiveGuestStartRequest
impl PartialEq for InteractiveGuestStartRequest
Sourcefn eq(&self, other: &InteractiveGuestStartRequest) -> bool
fn eq(&self, other: &InteractiveGuestStartRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for InteractiveGuestStartRequest
impl ResourceTypeMarker for InteractiveGuestStartRequest
Sourcetype Borrowed<'a> = &'a mut InteractiveGuestStartRequest
type Borrowed<'a> = &'a mut InteractiveGuestStartRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for InteractiveGuestStartRequest
impl TypeMarker for InteractiveGuestStartRequest
Sourcetype Owned = InteractiveGuestStartRequest
type Owned = InteractiveGuestStartRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for InteractiveGuestStartRequest
impl StructuralPartialEq for InteractiveGuestStartRequest