pub struct InteractiveGuestSynchronousProxy { /* private fields */ }Implementations
Sourceimpl InteractiveGuestSynchronousProxy
impl InteractiveGuestSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<InteractiveGuestEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<InteractiveGuestEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn put_file(
&self,
local_file: ClientEnd<FileMarker>,
remote_path: &str,
___deadline: MonotonicInstant,
) -> Result<i32, Error>
pub fn put_file( &self, local_file: ClientEnd<FileMarker>, remote_path: &str, ___deadline: MonotonicInstant, ) -> Result<i32, Error>
Take a local file from the Fuchsia host and transfer it to a destination location on the guest under test.
Sourcepub fn get_file(
&self,
remote_path: &str,
local_file: ClientEnd<FileMarker>,
___deadline: MonotonicInstant,
) -> Result<i32, Error>
pub fn get_file( &self, remote_path: &str, local_file: ClientEnd<FileMarker>, ___deadline: MonotonicInstant, ) -> Result<i32, Error>
Pull a file from the guest under test and copy it to the specified location on the Fuchsia host.
Sourcepub fn execute_command(
&self,
command: &str,
env: &[EnvironmentVariable],
stdin: Option<Socket>,
stdout: Option<Socket>,
stderr: Option<Socket>,
command_listener: ServerEnd<CommandListenerMarker>,
) -> Result<(), Error>
pub fn execute_command( &self, command: &str, env: &[EnvironmentVariable], stdin: Option<Socket>, stdout: Option<Socket>, stderr: Option<Socket>, command_listener: ServerEnd<CommandListenerMarker>, ) -> Result<(), Error>
Execute command on the guest under test and return the resulting output, error, and return code.
pub fn start( &self, guest_type: GuestType, name: &str, guest_config: GuestConfig, ___deadline: MonotonicInstant, ) -> Result<(), Error>
pub fn shutdown(&self, ___deadline: MonotonicInstant) -> Result<(), Error>